@@ -37,6 +37,26 @@ from dob_bright.termio.errors import dob_in_user_exit, dob_in_user_warning
 from dob_bright.termio.paging import flush_pager
 
 from dob_viewer.crud.fact_dressed import FactDressed
+from dob_viewer.config.styling.ignore_cmds import (
+    create_ignore_conf,
+    echo_ignore_sections,
+    echo_ignore_table,
+    edit_ignore_file
+)
+from dob_viewer.config.styling.rules_cmds import (
+    create_rules_conf,
+    echo_rules_conf,
+    echo_rule_names,
+    echo_rules_table,
+    edit_rules_conf
+)
+from dob_viewer.config.styling.styles_cmds import (
+    create_styles_conf,
+    echo_styles_conf,
+    echo_styles_list,
+    echo_styles_table,
+    edit_styles_conf
+)
 
 from .clickux import help_strings
 from .clickux import help_string_add_fact
@@ -49,7 +69,8 @@ from .clickux.bunchy_help import (
     cmd_bunch_group_datastore,
     cmd_bunch_group_dbms,
     cmd_bunch_group_add_fact,
-    cmd_bunch_group_ongoing_fact
+    cmd_bunch_group_ongoing_fact,
+    cmd_bunch_group_personalize
 )
 from .clickux.cmd_options import (
     OptionWithDynamicHelp,
@@ -67,7 +88,10 @@ from .clickux.cmd_options import (
     cmd_options_list_activitied,
     cmd_options_list_categoried,
     cmd_options_list_fact,
+    cmd_options_rule_name,
     cmd_options_search,
+    cmd_options_styles_internal,
+    cmd_options_styles_named,
     cmd_options_table_renderer,
     cmd_options_table_view,
     cmd_options_usage,
@@ -80,7 +104,6 @@ from .clickux.help_detect import show_help_finally, show_help_if_no_command
 from .clickux.induct_newbies import induct_newbies, insist_germinated
 from .clickux.plugin_group import ensure_plugged_in
 from .clickux.post_processor import post_processor
-from . import migrate
 from .cmds_list import activity as list_activity
 from .cmds_list import category as list_category
 from .cmds_list import fact as list_fact
@@ -89,6 +112,12 @@ from .cmds_usage import activity as usage_activity
 from .cmds_usage import category as usage_category
 from .cmds_usage import tag as usage_tag
 from .complete import tab_complete
+from .config import (
+    echo_config_table,
+    echo_config_value,
+    edit_config_file,
+    write_config_value
+)
 from .copyright import echo_copyright, echo_license
 from .demo import demo_config, demo_dob
 from .details import echo_app_details, echo_app_environs, echo_data_stats
@@ -98,13 +127,20 @@ from .facts.echo_fact import echo_latest_ended, echo_ongoing_fact, echo_ongoing_
 from .facts.edit_fact import edit_fact_by_pk
 from .facts.export_facts import export_facts
 from .facts.import_facts import import_facts
+from .migrate import control as migrate_control
+from .migrate import downgrade as migrate_downgrade
+from .migrate import upgrade as migrate_upgrade
 from .migrate import upgrade_legacy_database_file
-from .run_cli import dob_versions, pass_controller, run
-from .settings import echo_config_table, echo_config_value, write_config_value
+from .migrate import version as migrate_version
+from .run_cli import dob_versions, pass_controller, pass_controller_context, run
 
 # __all__ = ( ... )  # So many. Too tedious to list.
 
 
+# ***
+# *** [HELP]
+# ***
+
 @cmd_bunch_group_get_meta
 @run.command(help=help_strings.HELP_HELP)
 # (lb): Should not need the help-finally decorator, but doesn't seem to hurt, either:
@@ -292,26 +328,38 @@ def config_group(ctx):
 @flush_pager
 @click.option('-f', '--force', is_flag=True,
               help=help_strings.CONFIG_CREATE_FORCE_HELP)
-@pass_controller
-def config_create(controller, force):
+@pass_controller_context
+@ensure_plugged_in
+def config_create(ctx, controller, force):
     """"""
     controller.create_config(force)
 
 
-# *** [CONFIG] DUMP
+# *** [CONFIG] SHOW
 
-@config_group.command('dump', aliases=['list'], help=help_strings.CONFIG_DUMP_HELP)
+@config_group.command('show', aliases=['dump'], help=help_strings.CONFIG_SHOW_HELP)
 @show_help_finally
 @flush_pager
 @cmd_options_table_renderer
 @click.argument('section', nargs=1, default='')
 @click.argument('keyname', nargs=1, default='')
-@pass_controller
-@click.pass_context
+@pass_controller_context
 @ensure_plugged_in
-def config_dump(ctx, controller, section='', keyname='', **kwargs):
+def config_show(ctx, controller, table_type, section='', keyname=''):
     """"""
-    echo_config_table(controller, section, keyname, **kwargs)
+    echo_config_table(controller, table_type, section, keyname)
+
+
+# *** [CONFIG] EDIT
+
+@config_group.command('edit', help=help_strings.CONFIG_EDIT_HELP)
+@show_help_finally
+@flush_pager
+@pass_controller_context
+@ensure_plugged_in
+def config_edit(ctx, controller):
+    """"""
+    edit_config_file(controller)
 
 
 # *** [CONFIG] GET
@@ -320,8 +368,7 @@ def config_dump(ctx, controller, section='', keyname='', **kwargs):
 @show_help_finally
 @flush_pager
 @click.argument('parts', nargs=-1, metavar='[SECTION] KEYNAME VALUE')
-@pass_controller
-@click.pass_context
+@pass_controller_context
 @ensure_plugged_in
 def config_value_get(ctx, controller, parts):
     """"""
@@ -334,8 +381,7 @@ def config_value_get(ctx, controller, parts):
 @show_help_finally
 @flush_pager
 @click.argument('parts', nargs=-1, metavar='[SECTION] KEYNAME VALUE')
-@pass_controller
-@click.pass_context
+@pass_controller_context
 @ensure_plugged_in
 def config_value_set(ctx, controller, parts):
     """"""
@@ -347,14 +393,248 @@ def config_value_set(ctx, controller, parts):
 @config_group.command('update', help=help_strings.CONFIG_UPDATE_HELP)
 @show_help_finally
 @flush_pager
-@pass_controller
-@click.pass_context
+@pass_controller_context
 @ensure_plugged_in
 def config_update(ctx, controller):
     """Write "missing" key values to the user configuration file."""
     controller.round_out_config()
 
 
+# ***
+# *** [STYLES] Commands.
+# ***
+
+@cmd_bunch_group_personalize
+@run.group('styles', help=help_strings.STYLES_GROUP_HELP, **run_group_kwargs)
+@show_help_finally
+@show_help_if_no_command
+@flush_pager
+@click.pass_context
+def styles_group(ctx):
+    """Base `styles` group command run prior to any of the dob-styles commands."""
+    pass  # The command group decorator prints help if no subcommand called.
+
+
+# *** [STYLES] CREATE
+
+@styles_group.command('create', aliases=['new'], help=help_strings.STYLES_CREATE_HELP)
+@show_help_finally
+@flush_pager
+@cmd_options_styles_named
+@click.option('-f', '--force', is_flag=True, help=help_strings.STYLES_CREATE_FORCE_HELP)
+@pass_controller_context
+@ensure_plugged_in
+def styles_create(ctx, controller, name, force):
+    """"""
+    create_styles_conf(controller, name, force)
+
+
+# *** [STYLES] CONF
+
+@styles_group.command('conf', help=help_strings.STYLES_CONF_HELP)
+@show_help_finally
+@flush_pager
+@cmd_options_styles_named
+@cmd_options_styles_internal
+# (lb): Cannot specify click.option name, and if just -a and --all, click uses
+# all as the function parameter, which shadows the built-in. So add --complete.
+@click.option('-a', '--complete', '--all', is_flag=True,
+              help=_('Include all possible settings, even those not set by the style.'))
+@pass_controller_context
+@ensure_plugged_in
+def styles_conf(ctx, controller, name, internal, complete):
+    """"""
+    echo_styles_conf(controller, name, internal, complete)
+
+
+# *** [STYLES] EDIT
+
+@styles_group.command('edit', help=help_strings.STYLES_EDIT_HELP)
+@show_help_finally
+@flush_pager
+@pass_controller_context
+@ensure_plugged_in
+def styles_edit(ctx, controller):
+    """"""
+    edit_styles_conf(controller)
+
+
+# *** [STYLES] LIST
+
+@styles_group.command('list', help=help_strings.STYLES_LIST_HELP)
+@show_help_finally
+@flush_pager
+@cmd_options_styles_internal
+@pass_controller_context
+@ensure_plugged_in
+def styles_list(ctx, controller, internal):
+    """"""
+    echo_styles_list(controller, internal)
+
+
+# *** [STYLES] SHOW
+
+@styles_group.command('show', aliases=['dump'], help=help_strings.STYLES_SHOW_HELP)
+@show_help_finally
+@flush_pager
+@cmd_options_styles_named
+@cmd_options_table_renderer
+@pass_controller_context
+@ensure_plugged_in
+def styles_show(ctx, controller, name, table_type):
+    """"""
+    echo_styles_table(controller, name, table_type)
+
+
+# ***
+# *** [RULES] Commands.
+# ***
+
+@cmd_bunch_group_personalize
+@run.group('rules', help=help_strings.RULES_GROUP_HELP, **run_group_kwargs)
+@show_help_finally
+@show_help_if_no_command
+@flush_pager
+@click.pass_context
+def rules_group(ctx):
+    """Base `rules` group command run prior to any of the dob-rules commands."""
+    pass  # The command group decorator prints help if no subcommand called.
+
+
+# *** [RULES] CREATE
+
+@rules_group.command('create', aliases=['new'], help=help_strings.RULES_CREATE_HELP)
+@show_help_finally
+@flush_pager
+@click.option('-f', '--force', is_flag=True, help=help_strings.RULES_CREATE_FORCE_HELP)
+@pass_controller_context
+@ensure_plugged_in
+def rules_create(ctx, controller, force):
+    """"""
+    create_rules_conf(controller, force)
+
+
+# *** [RULES] CONF
+
+@rules_group.command('conf', help=help_strings.RULES_CONF_HELP)
+@show_help_finally
+@flush_pager
+@cmd_options_rule_name
+# (lb): Cannot specify click.option name, and if just -a and --all, click uses
+# all as the function parameter, which shadows the built-in. So add --complete.
+@click.option('-a', '--complete', '--all', is_flag=True,
+              help=_('Include all possible settings, even those not set by the style.'))
+@pass_controller_context
+@ensure_plugged_in
+def rules_conf(ctx, controller, name, complete):
+    """"""
+    echo_rules_conf(controller, name, complete)
+
+
+# *** [RULES] EDIT
+
+@rules_group.command('edit', help=help_strings.RULES_EDIT_HELP)
+@show_help_finally
+@flush_pager
+@pass_controller_context
+@ensure_plugged_in
+def rules_edit(ctx, controller):
+    """"""
+    edit_rules_conf(controller)
+
+
+# *** [RULES] LIST
+
+@rules_group.command('list', help=help_strings.RULES_LIST_HELP)
+@show_help_finally
+@flush_pager
+@pass_controller_context
+@ensure_plugged_in
+def rules_list(ctx, controller):
+    """"""
+    echo_rule_names(controller)
+
+
+# *** [RULES] SHOW
+
+@rules_group.command('show', aliases=['dump'], help=help_strings.RULES_SHOW_HELP)
+@show_help_finally
+@flush_pager
+@cmd_options_rule_name
+@cmd_options_table_renderer
+@pass_controller_context
+@ensure_plugged_in
+def rules_show(ctx, controller, name, table_type):
+    """"""
+    echo_rules_table(controller, name, table_type)
+
+
+# ***
+# *** [IGNORE] Commands.
+# ***
+
+@cmd_bunch_group_personalize
+@run.group('ignore', help=help_strings.IGNORE_GROUP_HELP, **run_group_kwargs)
+@show_help_finally
+@show_help_if_no_command
+@flush_pager
+@click.pass_context
+def ignore_group(ctx):
+    """Base `ignore` group command run prior to any of the dob-ignore commands."""
+    pass  # The command group decorator prints help if no subcommand called.
+
+
+# *** [IGNORE] CREATE
+
+@ignore_group.command('create', aliases=['new'], help=help_strings.IGNORE_CREATE_HELP)
+@show_help_finally
+@flush_pager
+@click.option('-f', '--force', is_flag=True, help=help_strings.IGNORE_CREATE_FORCE_HELP)
+@pass_controller_context
+@ensure_plugged_in
+def ignore_create(ctx, controller, force):
+    """"""
+    create_ignore_conf(controller, force)
+
+
+# *** [IGNORE] EDIT
+
+@ignore_group.command('edit', help=help_strings.IGNORE_EDIT_HELP)
+@show_help_finally
+@flush_pager
+@pass_controller_context
+@ensure_plugged_in
+def ignore_edit(ctx, controller):
+    """"""
+    edit_ignore_file(controller)
+
+
+# *** [IGNORE] LIST
+
+@ignore_group.command('list', help=help_strings.IGNORE_LIST_HELP)
+@show_help_finally
+@flush_pager
+@pass_controller_context
+@ensure_plugged_in
+def ignore_list(ctx, controller):
+    """"""
+    echo_ignore_sections(controller)
+
+
+# *** [IGNORE] SHOW
+
+@ignore_group.command('show', aliases=['dump'], help=help_strings.IGNORE_SHOW_HELP)
+@show_help_finally
+@flush_pager
+@cmd_options_rule_name
+@cmd_options_table_renderer
+@pass_controller_context
+@ensure_plugged_in
+def ignore_show(ctx, controller, name, table_type):
+    """"""
+    echo_ignore_table(controller, name, table_type)
+
+
 # ***
 # *** [STORE] Commands.
 # ***
@@ -407,8 +687,7 @@ def store_url(controller):
 @click.argument('filename', nargs=1, type=click.File('r'), required=False)
 @click.option('-f', '--force', is_flag=True,
               help=help_strings.STORE_UPGRADE_FORCE_HELP)
-@pass_controller
-@click.pass_context
+@pass_controller_context
 @post_processor
 def upgrade_legacy(ctx, controller, force, filename=None):
     """Migrate a legacy "Hamster" database."""
@@ -424,9 +703,9 @@ def upgrade_legacy(ctx, controller, force, filename=None):
 @run.command('stats', help=help_strings.STATS_HELP)
 @show_help_finally
 @flush_pager
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def nark_stats(controller):
+def nark_stats(ctx, controller):
     """List stats about the user's data."""
     echo_data_stats(controller)
 
@@ -442,8 +721,7 @@ def nark_stats(controller):
 @show_help_finally
 @show_help_if_no_command
 @flush_pager
-@pass_controller
-@click.pass_context
+@pass_controller_context
 def list_group(ctx, controller):
     """Base `list` group command run prior to any of the dob-list commands."""
     pass
@@ -459,9 +737,9 @@ def list_group(ctx, controller):
 @cmd_options_usage
 @cmd_options_table_view
 @cmd_options_limit_offset
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def list_activities(controller, *args, usage=False, **kwargs):
+def list_activities(ctx, controller, *args, usage=False, **kwargs):
     """List matching activities, filtered and sorted."""
     category = postprocess_options_list_categoried(kwargs)
     postprocess_options_table_options(kwargs)
@@ -485,9 +763,9 @@ def list_activities(controller, *args, usage=False, **kwargs):
 @cmd_options_usage
 @cmd_options_table_view
 @cmd_options_limit_offset
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def list_categories(controller, *args, usage=False, **kwargs):
+def list_categories(ctx, controller, *args, usage=False, **kwargs):
     """List matching categories, filtered and sorted."""
     postprocess_options_table_options(kwargs)
     if usage:
@@ -512,9 +790,9 @@ def list_categories(controller, *args, usage=False, **kwargs):
 @cmd_options_usage
 @cmd_options_table_view
 @cmd_options_limit_offset
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def list_tags(controller, *args, usage=False, **kwargs):
+def list_tags(ctx, controller, *args, usage=False, **kwargs):
     """List all tags, with filtering and sorting options."""
     activity = postprocess_options_list_activitied(kwargs)
     category = postprocess_options_list_categoried(kwargs)
@@ -560,9 +838,9 @@ def generate_list_facts_command(func):
     @cmd_options_table_view
     @cmd_options_limit_offset
     @cmd_options_list_fact
-    @pass_controller
+    @pass_controller_context
     @induct_newbies
-    def dob_list_facts(controller, *args, doc, **kwargs):
+    def dob_list_facts(ctx, controller, *args, doc, **kwargs):
         _list_facts(controller, *args, block_format=doc, **kwargs)
     return update_wrapper(dob_list_facts, func)
 
@@ -596,8 +874,7 @@ def search_facts(controller, *args, **kwargs):
 @show_help_finally
 @show_help_if_no_command
 @flush_pager
-@pass_controller
-@click.pass_context
+@pass_controller_context
 def usage_group(ctx, controller):
     """Base `usage` group command run prior to any of the dob-usage commands."""
     pass
@@ -612,9 +889,9 @@ def usage_group(ctx, controller):
 @cmd_options_list_categoried
 @cmd_options_table_view
 @cmd_options_limit_offset
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def usage_activities(controller, *args, **kwargs):
+def usage_activities(ctx, controller, *args, **kwargs):
     """List all activities. Provide optional filtering by name."""
     category = postprocess_options_list_categoried(kwargs)
     postprocess_options_table_options(kwargs)
@@ -634,9 +911,9 @@ def usage_activities(controller, *args, **kwargs):
 @cmd_options_search
 @cmd_options_table_view
 @cmd_options_limit_offset
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def usage_categories(controller, *args, **kwargs):
+def usage_categories(ctx, controller, *args, **kwargs):
     """List all categories. Provide optional filtering by name."""
     postprocess_options_table_options(kwargs)
     usage_category.usage_categories(
@@ -656,9 +933,9 @@ def usage_categories(controller, *args, **kwargs):
 @cmd_options_list_categoried
 @cmd_options_table_view
 @cmd_options_limit_offset
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def usage_tags(controller, *args, **kwargs):
+def usage_tags(ctx, controller, *args, **kwargs):
     """List all tags' usage counts, with filtering and sorting options."""
     activity = postprocess_options_list_activitied(kwargs)
     category = postprocess_options_list_categoried(kwargs)
@@ -682,9 +959,9 @@ def usage_tags(controller, *args, **kwargs):
 @cmd_options_list_categoried
 @cmd_options_table_view
 @cmd_options_limit_offset
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def usage_facts(controller, *args, **kwargs):
+def usage_facts(ctx, controller, *args, **kwargs):
     """List all tags' usage counts, with filtering and sorting options."""
     activity = postprocess_options_list_activitied(kwargs)
     category = postprocess_options_list_categoried(kwargs)
@@ -711,9 +988,8 @@ def usage_facts(controller, *args, **kwargs):
     '-f', '--force', '--purge', is_flag=True,
     help=_('Completely delete Fact, rather than just marking deleted.'),
 )
-@pass_controller
+@pass_controller_context
 @induct_newbies
-@click.pass_context
 @post_processor
 def cancel(ctx, controller, force):
     """Cancel the active Fact. Do not store the Fact in the backend."""
@@ -724,9 +1000,9 @@ def cancel(ctx, controller, force):
 @run.command('current', help=help_strings.CURRENT_HELP)
 @show_help_finally
 @flush_pager
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def current(controller):
+def current(ctx, controller):
     """Display the active Fact."""
     echo_ongoing_fact(controller)
 
@@ -735,9 +1011,9 @@ def current(controller):
 @run.command('latest', aliases=['last'], help=help_strings.LATEST_HELP)
 @show_help_finally
 @flush_pager
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def latest(controller):
+def latest(ctx, controller):
     """Display the last saved Fact."""
     echo_latest_ended(controller)
 
@@ -746,9 +1022,9 @@ def latest(controller):
 @run.command('show', help=help_strings.HELP_CMD_SHOW)
 @show_help_finally
 @flush_pager
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def show(controller):
+def show(ctx, controller):
     """Display the latest saved, or the active Fact."""
     echo_ongoing_or_ended(controller)
 
@@ -761,9 +1037,8 @@ def generate_add_fact_command(time_hint):
     def _generate_add_fact_command(func):
         @cmd_options_fact_add
         @cmd_options_fact_dryable
-        @pass_controller
+        @pass_controller_context
         @induct_newbies
-        @click.pass_context
         @post_processor
         def _add_fact(ctx, controller, *args, editor, **kwargs):
             return add_fact(
@@ -966,9 +1241,8 @@ add_group_kwargs = {
 @cmd_options_factoid
 @cmd_options_fact_add
 @cmd_options_fact_dryable
-@pass_controller
+@pass_controller_context
 @induct_newbies
-@click.pass_context
 @post_processor
 def add_group(ctx, controller, *args, **kwargs):
     """Base `add` group command run prior to any of the dob-add commands."""
@@ -990,9 +1264,8 @@ def add_group(ctx, controller, *args, **kwargs):
 @cmd_options_factoid
 @cmd_options_fact_add
 @cmd_options_fact_dryable
-@pass_controller
+@pass_controller_context
 @induct_newbies
-@click.pass_context
 @post_processor
 def add_help(*args, **kwargs):
     """Misdirecting "add --help" command to improve general help."""
@@ -1009,9 +1282,8 @@ def add_help(*args, **kwargs):
 @flush_pager
 @cmd_options_edit_item
 @cmd_options_fact_edit
-@pass_controller
+@pass_controller_context
 @induct_newbies
-@click.pass_context
 @post_processor
 def edit_group(ctx, controller, *args, **kwargs):
     """Base `edit` group command run prior to any of the dob-edit commands."""
@@ -1123,11 +1395,9 @@ def cmd_export_opt_output_default(controller):
 @cmd_options_limit_offset
 @cmd_options_list_activitied
 @cmd_options_list_categoried
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def transcode_export(
-    controller, *args, output, format, **kwargs
-):
+def transcode_export(ctx, controller, *args, output, format, **kwargs):
     """Export all facts of within a given timewindow to a file of specified format."""
     def _transcode_export():
         activity = postprocess_options_list_activitied(kwargs)
@@ -1182,9 +1452,8 @@ def transcode_export(
               help=_('Leave working backup file after commit'))
 @cmd_options_fact_dryable
 @cmd_options_fact_import
-@pass_controller
+@pass_controller_context
 @induct_newbies
-@click.pass_context
 @post_processor
 def transcode_import(
     ctx,
@@ -1266,9 +1535,9 @@ def transcode_import(
 @run.command('complete', hidden=True, help=help_strings.COMPLETE_HELP)
 @show_help_finally
 @flush_pager
-@pass_controller
+@pass_controller_context
 @induct_newbies
-def complete(controller):
+def complete(ctx, controller):
     """Bash tab-completion helper."""
     controller.disable_logging()
     tab_complete(controller)
@@ -1283,8 +1552,7 @@ def complete(controller):
 @show_help_finally
 @show_help_if_no_command
 @flush_pager
-@pass_controller
-@click.pass_context
+@pass_controller_context
 def migrate_group(ctx, controller):
     """Base `migrate` group command run prior to any of the dob-migrate commands."""
     pass
@@ -1293,41 +1561,41 @@ def migrate_group(ctx, controller):
 @migrate_group.command('control', help=help_strings.MIGRATE_CONTROL_HELP)
 @show_help_finally
 @flush_pager
-@pass_controller
+@pass_controller_context
 @insist_germinated
-def migrate_control(controller):
+def _migrate_control(ctx, controller):
     """Mark a database as under version control."""
-    migrate.control(controller)
+    migrate_control(controller)
 
 
 @migrate_group.command('down', help=help_strings.MIGRATE_DOWN_HELP)
 @show_help_finally
 @flush_pager
-@pass_controller
+@pass_controller_context
 @insist_germinated
-def migrate_downgrade(controller):
+def _migrate_downgrade(ctx, controller):
     """Downgrade the database according to its migration version."""
-    migrate.downgrade(controller)
+    migrate_downgrade(controller)
 
 
 @migrate_group.command('up', help=help_strings.MIGRATE_UP_HELP)
 @show_help_finally
 @flush_pager
-@pass_controller
+@pass_controller_context
 @insist_germinated
-def migrate_upgrade(controller):
+def _migrate_upgrade(ctx, controller):
     """Upgrade the database according to its migration version."""
-    migrate.upgrade(controller)
+    migrate_upgrade(controller)
 
 
 @migrate_group.command('version', help=help_strings.MIGRATE_VERSION_HELP)
 @show_help_finally
 @flush_pager
-@pass_controller
+@pass_controller_context
 @insist_germinated
-def migrate_version(controller):
+def _migrate_version(ctx, controller):
     """Show migration information about the database."""
-    migrate.version(controller)
+    migrate_version(controller)
 
 
 # 2018-07-15 14:00ish: To loaded: 0.440 secs.
